
# import pygame
import pygame as pyg
from pygame.locals import *
import Numeric

# try to import psyco
try:
    import psyco
except ImportError:
    pass
else:
    from psyco.classes import *
    psyco.full()

class Slider(pyg.sprite.Sprite):
        def __init__(self, app):
            pyg.sprite.Sprite.__init__(self)
            self.image = pyg.image.load("gfx/slider.png")
            self.rect = (10,350,100,20)
            self.pressure = 230
            self.app = app
            self.state = 0
            self.count = 0
        def draw(self, screen):
            screen.blit(self.image, self.rect)
        def up(self):            
            if self.pressure < 560:
                self.pressure += 15
                self.rect = (self.rect[0], self.rect[1]-15,self.rect[2], self.rect[3])
            else:
                #self.app.quit = 1
                return
        def down(self):            
            if self.pressure >0:
                self.pressure -= 10
                self.rect = (self.rect[0], self.rect[1]+10,self.rect[2], self.rect[3])
                return 1
            else:
                #self.app.quit = 1
                self.app.iron.state = 0
                return 0
        def s(self):
            if self.state == 0:
                self.state = 1
                self.count = self.app.frames
                return
            if self.state == 1:
                self.count = self.app.frames
                return
            if self.state == 2:
                self.state = 1
                self.count = self.app.frames
                return
        def w(self):
            if self.state == 0:
                self.state = 2
                return
            if self.state == 2:
                self.count = self.app.frames
                return
            if self.state == 1:
                n = (self.app.frames - self.count)
                if n < 15:
                    self.up()
                self.state = 2
                return
        
class ActionWin:
    def __init__(self):
        tile = pyg.image.load("gfx/pattern.png")
        self.surface = pyg.Surface((640,560))
        self.clothing = None
        for i in range(0,8):
            for j in range(0,7):
                self.surface.blit(tile, (i*80,j*80,80,80) )
    def draw(self, screen):
        s = self.surface.copy()
        if self.clothing:
            self.clothing.draw(s)
        screen.blit(s, (140,20,640,560))
        return

class Clothing:
    def __init__(self, level):
        self.image = pyg.image.load("gfx/" + level + ".png")
        self.creasedimage = pyg.image.load("gfx/creases" + level + ".png")# + file)
        self.i1 = pyg.surfarray.array2d(self.image)
        self.blank = pyg.image.load("gfx/blank.png")        
    def nocrease(self, rect):
        self.creasedimage.fill(0x00000000, rect)
    def draw(self, s):
        s.blit(self.image, (0,0, self.image.get_width(), self.image.get_height()))
        s.blit(self.creasedimage, (0,0, self.image.get_width(), self.image.get_height()))

class Iron:
    def __init__(self):
        self.imageoff = pyg.image.load("gfx/iron.png")
        self.imageon = pyg.image.load("gfx/ironsteam.png")
        
        self.rect = self.imageoff.get_rect()
        self.state = 0
    def draw(self, screen):
        self.rect.center = pyg.mouse.get_pos()
        if self.state == 0:
            screen.blit(self.imageoff, self.rect)
        if self.state == 1:
            screen.blit(self.imageon, self.rect.inflate(16,0))

class Timer:
    def __init__(self):
        self.value = 45
        self.ticks = 0
        self.font = pyg.font.Font("freesansbold.ttf", 36)
    def draw(self, screen):
        text = self.font.render(str(self.value), 1, (255,255,255,255), (0,0,0,0))
        screen.blit(text, text.get_rect(topright=(770,30)))
    def tick(self):
        self.ticks += 1
        if self.ticks == 10:
            self.ticks = 0
            self.value -= 1


class App:
    def __init__(self):
        pyg.init()
        self.screen = pyg.display.set_mode((800,600))
        self.splash = pyg.image.load("gfx/splash.png")
        self.menubg = pyg.image.load("gfx/menu.png")
        self.instrucbg = pyg.image.load("gfx/instructions.png")
        self.clock = pyg.time.Clock()
        self.guage = pyg.image.load("gfx/guage.png")
        self.levelend = pyg.image.load("gfx/levelend.png")
        self.gameover = pyg.image.load("gfx/gameover.png")
        self.slider = Slider(self)
        self.actionwin = None
        self.timer = None
        self.frames = 0
        self.iron = Iron()
        self.state = 1
        self.level = 0
        self.levels = ["blouse", "pants", "trousers", "shirt", "skirt"]
        return
    def run(self):
        pyg.mixer.init()
        #pyg.mixer.music.load("first2.ogg")
        #pyg.mixer.music.play(-1)
        self.pumpchannel = pyg.mixer.Channel(0)
        self.ironchannel = pyg.mixer.Channel(1)
        self.pumpin = pyg.mixer.Sound("in.ogg")
        self.pumpout = pyg.mixer.Sound("out.ogg")
        self.steamfx = pyg.mixer.Sound("iron.ogg")
        while self.state != 0:            
            self.clock.tick(60)
            self.frames += 1            
            if self.frames < 150:
                self.screen.blit(self.splash, (0,0))
                pyg.display.update()
            elif self.state == 1:
                self.menu()
            elif self.state == 2 or self.state == 3:
                self.game()
            elif self.state == 4:
                self.instructions()


    def game(self):
        if self.timer:
            if self.timer.value == 0:
                pyg.mixer.stop()
                self.state = 3
                self.screen.blit(self.gameover, (0,0))
                for event in pyg.event.get():
                    if event.type == QUIT:
                        self.state = 0
                        return
                    elif event.type == KEYDOWN and (event.key == K_RETURN or event.key == K_KP_ENTER):
                        self.timer = None
                        self.actionwin = None
                        self.level = 0
                        self.state = 1
                pyg.display.update()        
                return
        win = 1
        if not self.actionwin and self.state == 2:
            self.slider = None
            self.slider = Slider(self)
            self.timer = Timer()
            self.iron.state = 0
            self.actionwin = ActionWin()
            try:
                self.actionwin.clothing = Clothing(self.levels[self.level])
            except IndexError:
                self.level = 0
                self.actionwin.clothing = Clothing(self.levels[self.level])
        if self.actionwin:        
            workingarray = pyg.surfarray.array_alpha(self.actionwin.clothing.creasedimage)
            for i in range(0, len(workingarray)):
                x = Numeric.nonzero(workingarray[i])
                x = x.tolist()
                if len(x)==0:
                    pass
                else:
                    #print x
                    win = 0
        if win == 1:
            self.state = 3
            pyg.mixer.stop()
            #print "You Win!"      
            self.screen.blit(self.levelend, (0,0))
            for event in pyg.event.get():
                if event.type == QUIT:
                    self.state = 0
                    return
                elif event.type == KEYDOWN and (event.key == K_RETURN or event.key == K_KP_ENTER):
                    self.actionwin = None
                    self.level += 1
                    self.state = 2
        else:
            self.timer.tick()
            for event in pyg.event.get():
                if event.type == QUIT:
                    self.state = 0
                    return
                if event.type == KEYDOWN:
                    if event.key == K_s:
                        self.slider.s()
                        self.pumpchannel.play(self.pumpin)
                    if event.key == K_w:
                        self.slider.w()
                        self.pumpchannel.play(self.pumpout)
                    if event.key == K_ESCAPE:
                        self.state = 1
                if event.type == MOUSEBUTTONDOWN:
                    if event.button == 1:
                        self.iron.state = 1
                        self.ironchannel.play(self.steamfx)
                if event.type == MOUSEBUTTONUP:
                    if event.button == 1:
                        self.iron.state = 0
                        self.ironchannel.stop()
            if self.iron.state == 1:
                if self.slider.down() == 1:
                    ironRect = self.iron.rect.inflate(-6,-8).move(-140,-20)
                    self.actionwin.clothing.nocrease(ironRect)
                else:
                    pass
                    #print "No Pressure!!!"
            self.screen.fill(0x000000)
            self.screen.blit(self.guage, (10,0))            
            self.actionwin.draw(self.screen)
            self.slider.draw(self.screen)
            self.timer.draw(self.screen)
            self.iron.draw(self.screen)
        pyg.display.update()
        
    def menu(self):
        irect = pyg.Rect(310,250,182,30)
        grect = pyg.Rect(320,350,156,30)
        for event in pyg.event.get():
            if event.type == QUIT:
                self.state = 0
                return
            if event.type == KEYDOWN and event.key == K_ESCAPE:
                self.state = 0
                return
            if event.type == MOUSEBUTTONDOWN:
                if irect.collidepoint(pyg.mouse.get_pos()):
                    self.state = 4
                elif grect.collidepoint(pyg.mouse.get_pos()):
                    self.state = 2
                return
        self.screen.blit(self.menubg, (0,0))
        pyg.display.update()

    def instructions(self):
        qrect = pyg.Rect(308,430,184,90)
        for event in pyg.event.get():
            if event.type == QUIT:
                self.state = 0
                return
            if event.type == KEYDOWN and event.key == K_ESCAPE:
                self.state = 0
                return
            if event.type == MOUSEBUTTONDOWN:
                if qrect.collidepoint(pyg.mouse.get_pos()):
                    self.state = 1
                    return
        self.screen.blit(self.instrucbg, (0,0))
        pyg.display.update()
             

# Run!
if __name__ == "__main__":
    app = App()
    app.run()